'use strict';
/*
 * Transforms pages[0..length].content from markdown to HTML
 */

var marked = require('marked');
var renderer = new marked.Renderer();
var highlightjs = require('highlight.js');
var jobs = require('./jobs');

var lang;

var opts = {
  highlight: function (code) {
    var h;
    if(lang) {
      if(highlightjs.getLanguage(lang))
        h = highlightjs.highlight(lang, code, true);
      else
        h = highlightjs.highlight(code);
    } else {
      h = highlightjs.highlightAuto(code);
    }
    return h.value;
  },
  renderer: renderer,
  gfm: true,
  tables: true,
  breaks: false,
  pedantic: false,
  sanitize: false,
  smartLists: true,
  smartypants: false,
};

var parser = new marked.Parser(opts);
var lexer = new marked.Lexer(opts);

var toURL = function(url) {
  return jobs.run('toURL', url);
}

var renderImage = function(href, title, text, curFilename, cfg) {
  return jobs.run('image', href, title, text, curFilename, cfg);
}

renderer.heading = function(text, level, raw) {
  return '<h'  +
    (level+2)  +
    ' id="'    +
    toURL(raw) +
    '">'       +
    text       +
    '</h'      +
    (level+2)  +
    '>\n';
}

renderer.paragraph = function(text) {
  if(text.match('\\<img')) return '<div class="has-image">'+text+'</div>\n';
  else return '<p>'+text+'</p>\n';
}

renderer._link = renderer.link;

module.exports = function(obj) {
  console.log('Build step: Markdown');
  var options = obj.config.options;
  renderer.link = function(href, title, text) {
    if(options.httponly) {
      if(href.match(/^https:\/\/ok1kvk.cz/))
        href = href.replace('https://', 'http://');
    }
    if(options.httpsonly) {
      if(href.match(/^http:\/\/ok1kvk.cz/))
        href = href.replace('http://', 'https://');
    }

    return renderer._link(href,title,text);
  };

  obj.pages.forEach(function(article) {
    renderer.image = function(href, title, text) {
      return renderImage(href, title, text, article.file, obj.config);
    };
    lang = article.metadata.lang;
    article.content = parser.parse(lexer.lex(article.content));
  });
  return Promise.resolve(obj);
}
